==> loading_more_list_library_fast-4.0.1.tar.gz: lib/model/status.dart <==
import 'package:freezed_annotation/freezed_annotation.dart';

part 'status.g.dart';

part 'status.freezed.dart';

///状态
@freezed
class IndicatorStatusModel with _$IndicatorStatusModel {
  const IndicatorStatusModel._();

  factory IndicatorStatusModel.none() = IndicatorStatusModelWithNone;

  factory IndicatorStatusModel.empty() = IndicatorStatusModelWithEmpty;

  factory IndicatorStatusModel.loadingMoreBusying() =
      IndicatorStatusModelWithLoadingMoreBusying;

  factory IndicatorStatusModel.fullScreenBusying() =
      IndicatorStatusModelWithFullScreenBusying;

  factory IndicatorStatusModel.error(
      {@JsonKey(
          fromJson: null,
          toJson: null,
          includeToJson: false,
          includeFromJson: false)
      Object? error,
      @JsonKey(
          fromJson: null,
          toJson: null,
          includeToJson: false,
          includeFromJson: false)
      StackTrace? stackTrace}) = IndicatorStatusModelWithError;

  factory IndicatorStatusModel.fullScreenError(
      {@JsonKey(
          fromJson: null,
          toJson: null,
          includeToJson: false,
          includeFromJson: false)
      Object? error,
      @JsonKey(
          fromJson: null,
          toJson: null,
          includeToJson: false,
          includeFromJson: false)
      StackTrace? stackTrace}) = IndicatorStatusModelWithFullScreenError;

  factory IndicatorStatusModel.noMoreLoad() =
      IndicatorStatusModelWithNoMoreLoad;

  factory IndicatorStatusModel.fromJson(Map<String, dynamic> json) =>
      _$IndicatorStatusModelFromJson(json);
}

==> loading_more_list_library_fast-4.0.2.tar.gz: lib/model/status.dart <==
import 'package:freezed_annotation/freezed_annotation.dart';

import '../loading_more_list_library_fast.dart';


part 'status.freezed.dart';

///状态
@freezed
class IndicatorStatusModel with _$IndicatorStatusModel {
  const IndicatorStatusModel._();

  factory IndicatorStatusModel.none() = IndicatorStatusModelWithNone;

  factory IndicatorStatusModel.empty() = IndicatorStatusModelWithEmpty;

  factory IndicatorStatusModel.loadingMoreBusying() =
      IndicatorStatusModelWithLoadingMoreBusying;

  factory IndicatorStatusModel.fullScreenBusying() =
      IndicatorStatusModelWithFullScreenBusying;

  factory IndicatorStatusModel.error(
      {@JsonKey(
          fromJson: null,
          toJson: null,
          includeToJson: false,
          includeFromJson: false)
      Object? error,
      @JsonKey(
          fromJson: null,
          toJson: null,
          includeToJson: false,
          includeFromJson: false)
      StackTrace? stackTrace,
        @JsonKey(
            fromJson: null,
            toJson: null,
            includeToJson: false,
            includeFromJson: false) required RefreshBase refreshBase
      }) = IndicatorStatusModelWithError;

  factory IndicatorStatusModel.fullScreenError(
      {@JsonKey(
          fromJson: null,
          toJson: null,
          includeToJson: false,
          includeFromJson: false)
      Object? error,
      @JsonKey(
          fromJson: null,
          toJson: null,
          includeToJson: false,
          includeFromJson: false)
      StackTrace? stackTrace,
        @JsonKey(
            fromJson: null,
            toJson: null,
            includeToJson: false,
            includeFromJson: false) required RefreshBase refreshBase}) = IndicatorStatusModelWithFullScreenError;

  factory IndicatorStatusModel.noMoreLoad() =
      IndicatorStatusModelWithNoMoreLoad;


}
